@@ -439,6 +439,8 @@ group_chat_send (GossipGroupChat *chat,
 
 	lm_connection_send (connection, m, NULL);
 	lm_message_unref (m);
+
+	gossip_app_status_force_nonaway ();
 }
 
 static void
@@ -1039,7 +1041,7 @@ group_chat_iter_compare_func (GtkTreeModel *model,
 static GossipChat *
 group_chat_priv_chat_new (GossipGroupChat *chat, GossipJID *jid)
 {
-	GossipChat       *priv_chat = NULL;;
+	GossipChat       *priv_chat = NULL;
 	GList            *l;
 	GossipRosterItem *item;
 /*	gchar            *name; */
